@@ -4,6 +4,12 @@ import pickle
 
 from boxx import np
 
+"""
+把 obj 转换 pickle, 通过 msgpack 以二进制形式传输
+有的情况可以考虑使用 rpyc
+不用json 的原因是 json 传 bin code 需要转 base64
+"""
+
 
 class TransportPack:
     @classmethod
@@ -32,7 +38,7 @@ class TransportPack:
     @classmethod
     def test(cls, obj=None):
         if obj is None:
-            img = boxx.uint8(np.random.random((2 ** 20)))
+            img = boxx.uint8(np.random.random((2**20)))
             obj = {"str": "abc", "img": img}
         with boxx.timeit("packed"):
             packed = cls.pack(obj)
@@ -50,4 +56,4 @@ class TransportPack:
 if __name__ == "__main__":
     from boxx import *
 
-    TransportPack.test(imread("/home/dl/mars火星.jpg"))
+    TransportPack.test()
